# UPnP for Twisted

`txupnp` is a python2/3 library to interact with UPnP gateways using Twisted

## Installation

```
git clone https://github.com/lbryio/txupnp.git
cd txupnp
pip install -e .
```

## Usage

```
usage: txupnp-cli [-h] [--debug_logging] command

positional arguments:
  command          debug_gateway | list_mappings

optional arguments:
  -h, --help       show this help message and exit
  --debug_logging
```


## License

This project is MIT licensed. For the full license, see [LICENSE](LICENSE).

## Contact

The primary contact for this project is @jackrobison
